==> aipo-8.0.1a.zip: aipo-8.0.1a/portlets/mygroup/src/main/java/com/aimluck/eip/modules/screens/MyGroupScreen.java <==
/*
 * Aipo is a groupware program developed by TOWN, Inc.
 * Copyright (C) 2004-2015 TOWN, Inc.
 * http://www.aipo.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.aimluck.eip.modules.screens;

import org.apache.jetspeed.services.logging.JetspeedLogFactoryService;
import org.apache.jetspeed.services.logging.JetspeedLogger;
import org.apache.turbine.util.RunData;
import org.apache.velocity.context.Context;

import com.aimluck.eip.mygroup.MyGroupSelectData;
import com.aimluck.eip.mygroup.util.MyGroupUtils;
import com.aimluck.eip.util.ALEipUtils;

/**
 * マイグループの一覧を処理するクラスです。 <br />
 * 
 */
public class MyGroupScreen extends ALVelocityScreen {

  /** logger */
  private static final JetspeedLogger logger = JetspeedLogFactoryService
    .getLogger(MyGroupScreen.class.getName());

  /**
   * 
   * @param rundata
   * @param context
   * @throws Exception
   */
  @Override
  protected void doOutput(RunData rundata, Context context) throws Exception {

    try {
      MyGroupSelectData listData = new MyGroupSelectData();
      listData.initField();
      listData.setRowsNum(Integer.parseInt(ALEipUtils.getPortlet(
        rundata,
        context).getPortletConfig().getInitParameter("p1a-rows")));
      listData.doViewList(this, rundata, context);

      String type = rundata.getParameters().getString("type", "");
      String layout_template;
      if (type.equals("popup")) {
        layout_template = "portlets/html/ja/ajax-mygroup-popup.vm";
      } else {
        layout_template = "portlets/html/ja/ajax-mygroup.vm";
      }

      setTemplate(rundata, context, layout_template);
    } catch (Exception ex) {
      logger.error("[MyGroupScreen] Exception.", ex);
      ALEipUtils.redirectDBError(rundata);
    }
  }

  /**
   * @return
   */
  @Override
  protected String getPortletName() {
    return MyGroupUtils.MYGROUP_PORTLET_NAME;
  }

}

==> aipo-8.1.1.zip: aipo-8.1.1/portlets/mygroup/src/main/java/com/aimluck/eip/modules/screens/MyGroupScreen.java <==
/*
 * Aipo is a groupware program developed by TOWN, Inc.
 * Copyright (C) 2004-2015 TOWN, Inc.
 * http://www.aipo.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package com.aimluck.eip.modules.screens;

import org.apache.jetspeed.services.logging.JetspeedLogFactoryService;
import org.apache.jetspeed.services.logging.JetspeedLogger;
import org.apache.turbine.util.RunData;
import org.apache.velocity.context.Context;

import com.aimluck.eip.mygroup.MyGroupSelectData;
import com.aimluck.eip.mygroup.util.MyGroupUtils;
import com.aimluck.eip.util.ALEipUtils;

/**
 * マイグループの一覧を処理するクラスです。 <br />
 * 
 */
public class MyGroupScreen extends ALVelocityScreen {

  /** logger */
  private static final JetspeedLogger logger = JetspeedLogFactoryService
    .getLogger(MyGroupScreen.class.getName());

  /**
   * 
   * @param rundata
   * @param context
   * @throws Exception
   */
  @Override
  protected void doOutput(RunData rundata, Context context) throws Exception {

    try {
      MyGroupSelectData listData = new MyGroupSelectData();
      listData.initField();
      listData.setRowsNum(Integer.parseInt(ALEipUtils.getPortlet(
        rundata,
        context).getPortletConfig().getInitParameter("p1a-rows")));
      listData.doViewList(this, rundata, context);

      String type = rundata.getParameters().getString("type", "");
      String layout_template;
      if (type.equals("popup")) {
        layout_template = "portlets/html/ajax-mygroup-popup.vm";
      } else {
        layout_template = "portlets/html/ajax-mygroup.vm";
      }

      setTemplate(rundata, context, layout_template);
    } catch (Exception ex) {
      logger.error("[MyGroupScreen] Exception.", ex);
      ALEipUtils.redirectDBError(rundata);
    }
  }

  /**
   * @return
   */
  @Override
  protected String getPortletName() {
    return MyGroupUtils.MYGROUP_PORTLET_NAME;
  }

}
